@@ -4,16 +4,16 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include "agentmanager.h"
 #include "agentinstance.h"
-#include "control.h"
+#include "agentmanager.h"
 #include "collection.h"
+#include "collectiondeletejob.h"
 #include "collectionfetchjob.h"
 #include "collectionfetchscope.h"
-#include "collectiondeletejob.h"
 #include "collectionmodifyjob.h"
-#include "entitydisplayattribute.h"
 #include "collectionsync_p.h"
+#include "control.h"
+#include "entitydisplayattribute.h"
 #include "qtest_akonadi.h"
 #include "resourceselectjob_p.h"
 
@@ -105,7 +105,7 @@ private:
     CollectionSync *prepareBenchmarkSyncer(const Collection::List &collections)
     {
         CollectionSync *syncer = new CollectionSync(QStringLiteral("akonadi_knut_resource_0"));
-        connect(syncer, SIGNAL(percent(KJob*,ulong)), this, SLOT(syncBenchmarkProgress(KJob*,ulong)));
+        connect(syncer, SIGNAL(percent(KJob *, ulong)), this, SLOT(syncBenchmarkProgress(KJob *, ulong)));
         syncer->setHierarchicalRemoteIds(false);
         syncer->setRemoteCollections(collections);
         return syncer;
@@ -120,7 +120,7 @@ private:
             }
         }
         for (const Collection &col : qAsConst(baseCols)) {
-            CollectionDeleteJob *del = new CollectionDeleteJob(col);
+            auto del = new CollectionDeleteJob(col);
             AKVERIFYEXEC(del);
         }
     }
@@ -128,8 +128,8 @@ private:
 public Q_SLOTS:
     void syncBenchmarkProgress(KJob *job, ulong percent)
     {
-        Q_UNUSED(job);
-        qDebug() << "CollectionSync progress:" <<  percent << "%";
+        Q_UNUSED(job)
+        qDebug() << "CollectionSync progress:" << percent << "%";
     }
 
 private Q_SLOTS:
@@ -154,7 +154,7 @@ private Q_SLOTS:
         Collection::List origCols = fetchCollections(resource);
         QVERIFY(!origCols.isEmpty());
 
-        CollectionSync *syncer = new CollectionSync(resource, this);
+        auto syncer = new CollectionSync(resource, this);
         syncer->setHierarchicalRemoteIds(hierarchicalRIDs);
         syncer->setRemoteCollections(origCols);
         AKVERIFYEXEC(syncer);
@@ -176,7 +176,7 @@ private Q_SLOTS:
         Collection::List origCols = fetchCollections(resource);
         QVERIFY(!origCols.isEmpty());
 
-        CollectionSync *syncer = new CollectionSync(resource, this);
+        auto syncer = new CollectionSync(resource, this);
         syncer->setHierarchicalRemoteIds(hierarchicalRIDs);
         syncer->setAutoDelete(false);
         QSignalSpy spy(syncer, &KJob::result);
@@ -190,7 +190,7 @@ private Q_SLOTS:
             l << origCols[i];
             syncer->setRemoteCollections(l);
             if (i < origCols.count() - 1) {
-                QTest::qWait(10);   // enter the event loop so itemsync actually can do something
+                QTest::qWait(10); // enter the event loop so itemsync actually can do something
             }
             QCOMPARE(spy.count(), 0);
         }
@@ -224,7 +224,7 @@ private Q_SLOTS:
         Collection::List origCols = fetchCollections(resource);
         QVERIFY(!origCols.isEmpty());
 
-        CollectionSync *syncer = new CollectionSync(resource, this);
+        auto syncer = new CollectionSync(resource, this);
         syncer->setHierarchicalRemoteIds(hierarchicalRIDs);
         syncer->setRemoteCollections(origCols, Collection::List());
         AKVERIFYEXEC(syncer);
@@ -288,7 +288,7 @@ private Q_SLOTS:
         Collection::List origCols = fetchCollections(resource);
         QVERIFY(!origCols.isEmpty());
 
-        CollectionSync *syncer = new CollectionSync(resource, this);
+        auto syncer = new CollectionSync(resource, this);
         syncer->setHierarchicalRemoteIds(hierarchicalRIDs);
         syncer->setAutoDelete(false);
         QSignalSpy spy(syncer, &KJob::result);
@@ -302,7 +302,7 @@ private Q_SLOTS:
             l << origCols[i];
             syncer->setRemoteCollections(l, Collection::List());
             if (i < origCols.count() - 1) {
-                QTest::qWait(10);   // enter the event loop so itemsync actually can do something
+                QTest::qWait(10); // enter the event loop so itemsync actually can do something
             }
             QCOMPARE(spy.count(), 0);
         }
@@ -332,7 +332,7 @@ private Q_SLOTS:
         Collection::List origCols = fetchCollections(resource);
         QVERIFY(!origCols.isEmpty());
 
-        CollectionSync *syncer = new CollectionSync(resource, this);
+        auto syncer = new CollectionSync(resource, this);
         syncer->setHierarchicalRemoteIds(hierarchicalRIDs);
         syncer->setRemoteCollections(Collection::List(), Collection::List());
         AKVERIFYEXEC(syncer);
@@ -356,16 +356,17 @@ private Q_SLOTS:
         col.attribute<EntityDisplayAttribute>(Akonadi::Collection::AddIfMissing)->setDisplayName(QStringLiteral("foo"));
         col.setContentMimeTypes(QStringList() << Akonadi::Collection::mimeType() << QStringLiteral("foo"));
         {
-            CollectionModifyJob *job = new CollectionModifyJob(col);
+            auto job = new CollectionModifyJob(col);
             AKVERIFYEXEC(job);
         }
 
         col.attribute<EntityDisplayAttribute>()->setDisplayName(QStringLiteral("default"));
         col.setContentMimeTypes(QStringList() << Akonadi::Collection::mimeType() << QStringLiteral("default"));
 
-        CollectionSync *syncer = new CollectionSync(resource, this);
+        auto syncer = new CollectionSync(resource, this);
         if (keepLocalChanges) {
-            syncer->setKeepLocalChanges(QSet<QByteArray>() << "ENTITYDISPLAY" << "CONTENTMIMETYPES");
+            syncer->setKeepLocalChanges(QSet<QByteArray>() << "ENTITYDISPLAY"
+                                                           << "CONTENTMIMETYPES");
         } else {
             syncer->setKeepLocalChanges(QSet<QByteArray>());
         }
@@ -374,7 +375,7 @@ private Q_SLOTS:
         AKVERIFYEXEC(syncer);
 
         {
-            CollectionFetchJob *job = new CollectionFetchJob(col, Akonadi::CollectionFetchJob::Base);
+            auto job = new CollectionFetchJob(col, Akonadi::CollectionFetchJob::Base);
             AKVERIFYEXEC(job);
             Collection resultCol = job->collections().first();
             if (keepLocalChanges) {
@@ -392,7 +393,7 @@ private Q_SLOTS:
         const QString resource(QStringLiteral("akonadi_knut_resource_0"));
         Collection col = fetchCollections(resource).first();
 
-        auto *syncer = new CollectionSync(resource, this);
+        auto syncer = new CollectionSync(resource, this);
         syncer->setStreamingEnabled(true);
         syncer->setRemoteCollections({col}, {});
 
