@@ -10,9 +10,9 @@
 #include "collectionstatistics.h"
 #include "control.h"
 #include "itemcopyjob.h"
+#include "itemcreatejob.h"
 #include "itemfetchjob.h"
 #include "itemfetchscope.h"
-#include "itemcreatejob.h"
 
 #include "qtest_akonadi.h"
 
@@ -30,7 +30,7 @@ private Q_SLOTS:
         AkonadiTest::checkTestIsIsolated();
         Control::start();
         // switch target resources offline to reduce interference from them
-        foreach (Akonadi::AgentInstance agent, Akonadi::AgentManager::self()->instances()) {   //krazy:exclude=foreach
+        foreach (Akonadi::AgentInstance agent, Akonadi::AgentManager::self()->instances()) { // krazy:exclude=foreach
             if (agent.identifier() == QLatin1String("akonadi_knut_resource_2")) {
                 agent.setIsOnline(false);
             }
@@ -46,11 +46,11 @@ private Q_SLOTS:
         AKVERIFYEXEC(copy);
 
         Item source(1);
-        ItemFetchJob *sourceFetch = new ItemFetchJob(source);
+        auto sourceFetch = new ItemFetchJob(source);
         AKVERIFYEXEC(sourceFetch);
         source = sourceFetch->items().first();
 
-        ItemFetchJob *fetch = new ItemFetchJob(target);
+        auto fetch = new ItemFetchJob(target);
         fetch->fetchScope().fetchFullPayload();
         fetch->fetchScope().fetchAllAttributes();
         fetch->fetchScope().setCacheOnly(true);
@@ -95,15 +95,15 @@ private Q_SLOTS:
         Item item(QStringLiteral("application/octet-stream"));
         item.setPayloadPath(file.fileName());
 
-        auto *create = new ItemCreateJob(item, source, this);
+        auto create = new ItemCreateJob(item, source, this);
         AKVERIFYEXEC(create);
         item = create->item();
 
         const Collection target(AkonadiTest::collectionIdFromPath(QStringLiteral("res2/space folder")));
-        auto *copy = new ItemCopyJob(item, target, this);
+        auto copy = new ItemCopyJob(item, target, this);
         AKVERIFYEXEC(copy);
 
-        auto *fetch = new ItemFetchJob(target, this);
+        auto fetch = new ItemFetchJob(target, this);
         fetch->fetchScope().fetchFullPayload(true);
         AKVERIFYEXEC(fetch);
         QCOMPARE(fetch->items().size(), 1);
@@ -114,7 +114,6 @@ private Q_SLOTS:
         QVERIFY(copiedItem.hasPayload<QByteArray>());
         QCOMPARE(copiedItem.payload<QByteArray>(), item.payload<QByteArray>());
     }
-
 };
 
 QTEST_AKONADIMAIN(ItemCopyTest)
