@@ -1,24 +1,11 @@
 /*
     This file is part of akonadiresources.
 
-    Copyright (c) 2006 Till Adam <adam@kde.org>
-    Copyright (c) 2007 Volker Krause <vkrause@kde.org>
-    Copyright (c) 2008 Kevin Krammer <kevin.krammer@gmx.at>
+    SPDX-FileCopyrightText: 2006 Till Adam <adam@kde.org>
+    SPDX-FileCopyrightText: 2007 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2008 Kevin Krammer <kevin.krammer@gmx.at>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef AKONADI_AGENTBASE_H
@@ -41,7 +28,6 @@ class KAboutData;
 
 namespace Akonadi
 {
-
 class AgentBasePrivate;
 class ChangeRecorder;
 class Collection;
@@ -77,7 +63,7 @@ class Item;
  * most notably AgentBase::config(). Additionally,
  * one cannot use QDBusConnection::sessionBus() with dbus < 1.4, because of a
  * multithreading bug in libdbus. Instead one should use
- * KDBusConnectionPool::threadConnection() which works around this problem.
+ * QDBusConnection::sessionBus() which works around this problem.
  *
  * @author Till Adam <adam@kde.org>, Volker Krause <vkrause@kde.org>
  */
@@ -187,7 +173,7 @@ public:
      *
      * @deprecated Use ObserverV2 instead
      */
-    class AKONADIAGENTBASE_DEPRECATED AKONADIAGENTBASE_EXPORT Observer  // krazy:exclude=dpointer
+    class AKONADIAGENTBASE_DEPRECATED AKONADIAGENTBASE_EXPORT Observer // krazy:exclude=dpointer
     {
     public:
         /**
@@ -224,7 +210,7 @@ public:
          * Reimplement to handle adding of new collections.
          * @param collection The newly added collection.
          * @param parent The parent collection.
-          */
+         */
         virtual void collectionAdded(const Akonadi::Collection &collection, const Akonadi::Collection &parent);
 
         /**
@@ -246,7 +232,7 @@ public:
      *
      * @since 4.4
      */
-    class AKONADIAGENTBASE_EXPORT ObserverV2 : public Observer  // krazy:exclude=dpointer
+    class AKONADIAGENTBASE_EXPORT ObserverV2 : public Observer // krazy:exclude=dpointer
     {
     public:
         using Observer::collectionChanged;
@@ -261,8 +247,7 @@ public:
          * @param collectionSource The collection the item has been moved from.
          * @param collectionDestination The collection the item has been moved to.
          */
-        virtual void itemMoved(const Akonadi::Item &item, const Akonadi::Collection &collectionSource,
-                               const Akonadi::Collection &collectionDestination);
+        virtual void itemMoved(const Akonadi::Item &item, const Akonadi::Collection &collectionSource, const Akonadi::Collection &collectionDestination);
 
         /**
          * Reimplement to handle item linking.
@@ -290,8 +275,8 @@ public:
          * @param collectionSource The previous parent collection.
          * @param collectionDestination The new parent collection.
          */
-        virtual void collectionMoved(const Akonadi::Collection &collection, const Akonadi::Collection &collectionSource,
-                                     const Akonadi::Collection &collectionDestination);
+        virtual void
+        collectionMoved(const Akonadi::Collection &collection, const Akonadi::Collection &collectionSource, const Akonadi::Collection &collectionDestination);
 
         /**
          * Reimplement to handle changes to existing collections.
@@ -341,8 +326,8 @@ public:
          * @param sourceCollection Collection from where the items were moved
          * @param destinationCollection Collection to which the items were moved
          */
-        virtual void itemsMoved(const Akonadi::Item::List &items, const Akonadi::Collection &sourceCollection,
-                                const Akonadi::Collection &destinationCollection);
+        virtual void
+        itemsMoved(const Akonadi::Item::List &items, const Akonadi::Collection &sourceCollection, const Akonadi::Collection &destinationCollection);
 
         /**
          * Reimplement to handle batch notifications about items linking.
@@ -423,9 +408,8 @@ public:
          * @param addedRelations the list of relations that were added to all @p items
          * @param removedRelations the list of relations that were removed from all @p items
          */
-        virtual void itemsRelationsChanged(const Akonadi::Item::List &items,
-                                           const Akonadi::Relation::List &addedRelations,
-                                           const Akonadi::Relation::List &removedRelations);
+        virtual void
+        itemsRelationsChanged(const Akonadi::Item::List &items, const Akonadi::Relation::List &addedRelations, const Akonadi::Relation::List &removedRelations);
     };
 
     /**
@@ -434,8 +418,8 @@ public:
      */
     enum Status {
         Idle = 0, ///< The agent does currently nothing.
-        Running,  ///< The agent is working on something.
-        Broken,    ///< The agent encountered an error state.
+        Running, ///< The agent is working on something.
+        Broken, ///< The agent encountered an error state.
         NotConfigured ///< The agent is lacking required configuration
     };
 
@@ -463,10 +447,8 @@ public:
      * @param argc number of arguments
      * @param argv arguments for the function
      */
-    template <typename T>
-    static int init(int argc, char **argv)
+    template<typename T> static int init(int argc, char **argv)
     {
-
         // Disable session management
         qunsetenv("SESSION_MANAGER");
 
@@ -477,7 +459,7 @@ public:
 
         // check if T also inherits AgentBase::Observer and
         // if it does, automatically register it on itself
-        Observer *observer = dynamic_cast<Observer *>(&r);
+        auto *observer = dynamic_cast<Observer *>(&r);
         if (observer != nullptr) {
             r.registerObserver(observer);
         }
@@ -567,7 +549,7 @@ public:
      * @since 4.3
      * @param name name of the agent
      */
-    //FIXME_API: make sure location is renamed to this by agentbase
+    // FIXME_API: make sure location is renamed to this by agentbase
     void setAgentName(const QString &name);
 
     /**
@@ -733,37 +715,37 @@ protected:
 
 protected:
     /**
-      * Sets the agent offline but will make it online again after a given time
-      *
-      * Use this method when the agent detects some problem with its backend but it wants
-      * to retry all pending operations after some time - e.g. a server can not be reached currently
-      *
-      * Example usage:
-      * @code
-      * void ExampleResource::onItemRemovedFinished(KJob *job)
-      * {
-      *     if (job->error()) {
-      *         Q_EMIT status(Broken, job->errorString());
-      *         deferTask();
-      *         setTemporaryOffline(300);
-      *         return;
-      *     }
-      *     ...
-      * }
-      * @endcode
-      *
-      * @since 4.13
-      * @param makeOnlineInSeconds timeout in seconds after which the agent changes to online
-      */
+     * Sets the agent offline but will make it online again after a given time
+     *
+     * Use this method when the agent detects some problem with its backend but it wants
+     * to retry all pending operations after some time - e.g. a server can not be reached currently
+     *
+     * Example usage:
+     * @code
+     * void ExampleResource::onItemRemovedFinished(KJob *job)
+     * {
+     *     if (job->error()) {
+     *         Q_EMIT status(Broken, job->errorString());
+     *         deferTask();
+     *         setTemporaryOffline(300);
+     *         return;
+     *     }
+     *     ...
+     * }
+     * @endcode
+     *
+     * @since 4.13
+     * @param makeOnlineInSeconds timeout in seconds after which the agent changes to online
+     */
     void setTemporaryOffline(int makeOnlineInSeconds = 300);
 
-    //@cond PRIVATE
+    /// @cond PRIVATE
     static void debugAgent(int argc, char **argv);
 
     AgentBasePrivate *d_ptr;
     explicit AgentBase(AgentBasePrivate *d, const QString &id);
     friend class ObserverV2;
-    //@endcond
+    /// @endcond
 
     /**
      * This method is called whenever the @p online status has changed.
@@ -775,7 +757,7 @@ protected:
     virtual KAboutData aboutData() const;
 
 private:
-    //@cond PRIVATE
+    /// @cond PRIVATE
     static QString parseArguments(int argc, char **argv);
     static int init(AgentBase &r);
     void setOnlineInternal(bool state);
@@ -799,7 +781,7 @@ private:
     Q_PRIVATE_SLOT(d_func(), void slotResumedFromSuspend())
     Q_PRIVATE_SLOT(d_func(), void slotTemporaryOfflineTimeout())
 
-    //@endcond
+    /// @endcond
 };
 
 }
@@ -808,10 +790,10 @@ private:
 /**
  * Convenience Macro for the most common main() function for Akonadi agents.
  */
-#define AKONADI_AGENT_MAIN( agentClass )                       \
-    int main( int argc, char **argv )                            \
-    {                                                            \
-        return Akonadi::AgentBase::init<agentClass>( argc, argv ); \
+#define AKONADI_AGENT_MAIN(agentClass)                                                                                                                         \
+    int main(int argc, char **argv)                                                                                                                            \
+    {                                                                                                                                                          \
+        return Akonadi::AgentBase::init<agentClass>(argc, argv);                                                                                               \
     }
 #endif
 
