@@ -1,21 +1,8 @@
 /*
-    Copyright (c) 2008 Kevin Krammer <kevin.krammer@gmx.at>
-    Copyright (c) 2009 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2008 Kevin Krammer <kevin.krammer@gmx.at>
+    SPDX-FileCopyrightText: 2009 Volker Krause <vkrause@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef AKONADI_COLLECTIONFETCHSCOPE_H
@@ -23,14 +10,13 @@
 
 #include "akonadicore_export.h"
 
-#include <QSharedDataPointer>
 #include <QSet>
+#include <QSharedDataPointer>
 
-class QStringList;
+#include <QStringList>
 
 namespace Akonadi
 {
-
 class CollectionFetchScopePrivate;
 
 /**
@@ -109,10 +95,10 @@ public:
      */
     enum ListFilter {
         NoFilter, ///< No filtering, retrieve all collections
-        Display,  ///< Only retrieve collections for display, taking the local preference and enabled into account.
-        Sync,     ///< Only retrieve collections for synchronization, taking the local preference and enabled into account.
-        Index,    ///< Only retrieve collections for indexing, taking the local preference and enabled into account.
-        Enabled   ///< Only retrieve enabled collections, ignoring the local preference.
+        Display, ///< Only retrieve collections for display, taking the local preference and enabled into account.
+        Sync, ///< Only retrieve collections for synchronization, taking the local preference and enabled into account.
+        Index, ///< Only retrieve collections for indexing, taking the local preference and enabled into account.
+        Enabled ///< Only retrieve enabled collections, ignoring the local preference.
     };
 
     /**
@@ -231,7 +217,7 @@ public:
      *
      * @param fetch @c true if the attribute should be fetched, @c false otherwise.
      */
-    template <typename T> inline void fetchAttribute(bool fetch = true)
+    template<typename T> inline void fetchAttribute(bool fetch = true)
     {
         T dummy;
         fetchAttribute(dummy.type(), fetch);
@@ -277,9 +263,9 @@ public:
     Q_REQUIRED_RESULT bool isEmpty() const;
 
 private:
-    //@cond PRIVATE
+    /// @cond PRIVATE
     QSharedDataPointer<CollectionFetchScopePrivate> d;
-    //@endcond
+    /// @endcond
 };
 
 }
