@@ -9,7 +9,6 @@
 
 #include "itemfetchscope.h"
 
-
 using namespace Akonadi;
 
 ItemMonitor::ItemMonitor()
@@ -40,10 +39,12 @@ void ItemMonitor::setItem(const Item &item)
     }
 
     // start initial fetch of the new item
-    ItemFetchJob *job = new ItemFetchJob(d->mItem);
+    auto job = new ItemFetchJob(d->mItem);
     job->setFetchScope(fetchScope());
 
-    d->connect(job, &ItemFetchJob::result, d, [this](KJob* job) {d->initialFetchDone(job); });
+    d->connect(job, &ItemFetchJob::result, d, [this](KJob *job) {
+        d->initialFetchDone(job);
+    });
 }
 
 Item ItemMonitor::item() const
