@@ -8,13 +8,13 @@
 #include "agenttypedialog.h"
 #include "agentfilterproxymodel.h"
 
-#include <QVBoxLayout>
 #include <KConfig>
+#include <QVBoxLayout>
 
-#include <KFilterProxySearchLine>
-#include <QLineEdit>
-#include <KSharedConfig>
 #include <KConfigGroup>
+#include <KFilterProxySearchLine>
+#include <KSharedConfig>
+#include <QLineEdit>
 
 #include <QDialogButtonBox>
 #include <QPushButton>
@@ -27,14 +27,13 @@ public:
     explicit Private(AgentTypeDialog *qq)
         : q(qq)
     {
-
     }
-    void readConfig(); 
+    void readConfig();
     void writeConfig() const;
     void slotSearchAgentType(const QString &str);
     AgentTypeWidget *Widget = nullptr;
     AgentType agentType;
-    AgentTypeDialog * const q;
+    AgentTypeDialog *const q;
 };
 
 void AgentTypeDialog::Private::writeConfig() const
@@ -61,12 +60,12 @@ AgentTypeDialog::AgentTypeDialog(QWidget *parent)
     : QDialog(parent)
     , d(new Private(this))
 {
-    QVBoxLayout *layout = new QVBoxLayout(this);
+    auto layout = new QVBoxLayout(this);
 
     d->Widget = new Akonadi::AgentTypeWidget(this);
     connect(d->Widget, &AgentTypeWidget::activated, this, &AgentTypeDialog::accept);
 
-    QLineEdit *searchLine = new QLineEdit(this);
+    auto searchLine = new QLineEdit(this);
     layout->addWidget(searchLine);
     searchLine->setClearButtonEnabled(true);
     connect(searchLine, &QLineEdit::textChanged, this, [this](const QString &str) {
@@ -75,7 +74,7 @@ AgentTypeDialog::AgentTypeDialog(QWidget *parent)
 
     layout->addWidget(d->Widget);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     connect(buttonBox, &QDialogButtonBox::accepted, this, &AgentTypeDialog::accept);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &AgentTypeDialog::reject);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
