@@ -1,21 +1,8 @@
 /*
-    Copyright 2008 Ingo Klöcker <kloecker@kde.org>
-    Copyright 2010-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2008 Ingo Klöcker <kloecker@kde.org>
+    SPDX-FileCopyrightText: 2010-2021 Laurent Montel <montel@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef AKONADI_COLLECTIONDIALOG_H
@@ -24,12 +11,11 @@
 #include "akonadiwidgets_export.h"
 #include "collection.h"
 
-#include <QDialog>
 #include <QAbstractItemView>
+#include <QDialog>
 
 namespace Akonadi
 {
-
 /**
  * @short A collection selection dialog.
  *
@@ -71,11 +57,7 @@ class AKONADIWIDGETS_EXPORT CollectionDialog : public QDialog
 public:
     /* @since 4.6
      */
-    enum CollectionDialogOption {
-        None = 0,
-        AllowToCreateNewChildCollection = 1,
-        KeepTreeExpanded = 2
-    };
+    enum CollectionDialogOption { None = 0, AllowToCreateNewChildCollection = 1, KeepTreeExpanded = 2 };
 
     Q_DECLARE_FLAGS(CollectionDialogOptions, CollectionDialogOption)
 
@@ -193,12 +175,12 @@ public:
     void changeCollectionDialogOptions(CollectionDialogOptions options);
 
     /**
-      * @since 4.13
-      */
+     * @since 4.13
+     */
     void setUseFolderByDefault(bool b);
     /**
-      * @since 4.13
-      */
+     * @since 4.13
+     */
     Q_REQUIRED_RESULT bool useFolderByDefault() const;
     /**
      * Allow to specify collection content mimetype when we create new one.
@@ -207,14 +189,10 @@ public:
     void setContentMimeTypes(const QStringList &mimetypes);
 
 private:
-    //@cond PRIVATE
+    /// @cond PRIVATE
     class Private;
     Private *const d;
-
-    Q_PRIVATE_SLOT(d, void slotSelectionChanged())
-    Q_PRIVATE_SLOT(d, void slotAddChildCollection())
-    Q_PRIVATE_SLOT(d, void slotDoubleClicked())
-    //@endcond
+    /// @endcond
 };
 
 } // namespace Akonadi
