@@ -13,20 +13,20 @@
 
 #include <shared/akranges.h>
 
-#include <QVBoxLayout>
+#include <QDesktopServices>
+#include <QDir>
 #include <QLabel>
 #include <QPushButton>
-#include <QTemporaryFile>
-#include <QDir>
-#include <QDesktopServices>
-#include <QWindow>
 #include <QScreen>
+#include <QTemporaryFile>
+#include <QVBoxLayout>
+#include <QWindow>
 
 #include <KColorScheme>
 #include <KLocalizedString>
-#include <QTextBrowser>
-#include <QDialogButtonBox>
 #include <KWindowConfig>
+#include <QDialogButtonBox>
+#include <QTextBrowser>
 
 using namespace Akonadi;
 using namespace AkRanges;
@@ -51,45 +51,43 @@ public:
         return mTextContent;
     }
 
-    void setPropertyNameTitle(const QString &title) override {
+    void setPropertyNameTitle(const QString &title) override
+    {
         mNameTitle = title;
     }
 
-    void setLeftPropertyValueTitle(const QString &title) override {
+    void setLeftPropertyValueTitle(const QString &title) override
+    {
         mLeftTitle = title;
     }
 
-    void setRightPropertyValueTitle(const QString &title) override {
+    void setRightPropertyValueTitle(const QString &title) override
+    {
         mRightTitle = title;
     }
 
-    void addProperty(Mode mode, const QString &name, const QString &leftValue, const QString &rightValue) override {
-        switch (mode)
-        {
+    void addProperty(Mode mode, const QString &name, const QString &leftValue, const QString &rightValue) override
+    {
+        switch (mode) {
         case NormalMode:
             mContent.append(QStringLiteral("<tr><td align=\"right\"><b>%1:</b></td><td>%2</td><td></td><td>%3</td></tr>")
-            .arg(name,
-            textToHTML(leftValue),
-            textToHTML(rightValue)));
+                                .arg(name, textToHTML(leftValue), textToHTML(rightValue)));
             mTextContent.append(QStringLiteral("%1:\n%2\n%3\n\n").arg(name, leftValue, rightValue));
             break;
         case ConflictMode:
-            mContent.append(QStringLiteral("<tr><td align=\"right\"><b>%1:</b></td><td bgcolor=\"#ff8686\">%2</td><td></td><td bgcolor=\"#ff8686\">%3</td></tr>")
-            .arg(name,
-            textToHTML(leftValue),
-            textToHTML(rightValue)));
+            mContent.append(
+                QStringLiteral("<tr><td align=\"right\"><b>%1:</b></td><td bgcolor=\"#ff8686\">%2</td><td></td><td bgcolor=\"#ff8686\">%3</td></tr>")
+                    .arg(name, textToHTML(leftValue), textToHTML(rightValue)));
             mTextContent.append(QStringLiteral("%1:\n%2\n%3\n\n").arg(name, leftValue, rightValue));
             break;
         case AdditionalLeftMode:
             mContent.append(QStringLiteral("<tr><td align=\"right\"><b>%1:</b></td><td bgcolor=\"#9cff83\">%2</td><td></td><td></td></tr>")
-            .arg(name,
-            textToHTML(leftValue)));
+                                .arg(name, textToHTML(leftValue)));
             mTextContent.append(QStringLiteral("%1:\n%2\n\n").arg(name, leftValue));
             break;
         case AdditionalRightMode:
             mContent.append(QStringLiteral("<tr><td align=\"right\"><b>%1:</b></td><td></td><td></td><td bgcolor=\"#9cff83\">%2</td></tr>")
-            .arg(name,
-            textToHTML(rightValue)));
+                                .arg(name, textToHTML(rightValue)));
             mTextContent.append(QStringLiteral("%1:\n%2\n\n").arg(name, rightValue));
             break;
         }
@@ -100,20 +98,21 @@ private:
     {
         QString header = QStringLiteral("<html>");
         header += QStringLiteral("<body text=\"%1\" bgcolor=\"%2\">")
-                  .arg(KColorScheme(QPalette::Active, KColorScheme::View).foreground().color().name(),
-                       KColorScheme(QPalette::Active, KColorScheme::View).background().color().name());
+                      .arg(KColorScheme(QPalette::Active, KColorScheme::View).foreground().color().name(),
+                           KColorScheme(QPalette::Active, KColorScheme::View).background().color().name());
         header += QLatin1String("<center><table>");
         header += QStringLiteral("<tr><th align=\"center\">%1</th><th align=\"center\">%2</th><td>&nbsp;</td><th align=\"center\">%3</th></tr>")
-                  .arg(mNameTitle, mLeftTitle, mRightTitle);
+                      .arg(mNameTitle, mLeftTitle, mRightTitle);
 
         return header;
     }
 
     QString footer() const
     {
-        return QStringLiteral("</table></center>"
-                              "</body>"
-                              "</html>");
+        return QStringLiteral(
+            "</table></center>"
+            "</body>"
+            "</html>");
     }
 
     QString mContent;
@@ -126,35 +125,43 @@ private:
 static void compareItems(AbstractDifferencesReporter *reporter, const Akonadi::Item &localItem, const Akonadi::Item &otherItem)
 {
     if (localItem.modificationTime() != otherItem.modificationTime()) {
-        reporter->addProperty(AbstractDifferencesReporter::ConflictMode, i18n("Modification Time"),
+        reporter->addProperty(AbstractDifferencesReporter::ConflictMode,
+                              i18n("Modification Time"),
                               QLocale().toString(localItem.modificationTime(), QLocale::ShortFormat),
                               QLocale().toString(otherItem.modificationTime(), QLocale::ShortFormat));
     }
 
     if (localItem.flags() != otherItem.flags()) {
-        const auto toQString = [](const QByteArray &s) { return QString::fromUtf8(s); };
+        const auto toQString = [](const QByteArray &s) {
+            return QString::fromUtf8(s);
+        };
         const auto localFlags = localItem.flags() | Views::transform(toQString) | Actions::toQList;
         const auto otherFlags = otherItem.flags() | Views::transform(toQString) | Actions::toQList;
-        reporter->addProperty(AbstractDifferencesReporter::ConflictMode, i18n("Flags"),
+        reporter->addProperty(AbstractDifferencesReporter::ConflictMode,
+                              i18n("Flags"),
                               localFlags.join(QLatin1String(", ")),
                               otherFlags.join(QLatin1String(", ")));
     }
 
-    const auto toPair = [](Attribute *attr) { return std::pair{attr->type(), attr->serialized()}; };
+    const auto toPair = [](Attribute *attr) {
+        return std::pair{attr->type(), attr->serialized()};
+    };
     const auto localAttributes = localItem.attributes() | Views::transform(toPair) | Actions::toQHash;
     const auto otherAttributes = otherItem.attributes() | Views::transform(toPair) | Actions::toQHash;
 
     if (localAttributes != otherAttributes) {
         for (const QByteArray &localKey : localAttributes) {
             if (!otherAttributes.contains(localKey)) {
-                reporter->addProperty(AbstractDifferencesReporter::AdditionalLeftMode, i18n("Attribute: %1", QString::fromUtf8(localKey)),
+                reporter->addProperty(AbstractDifferencesReporter::AdditionalLeftMode,
+                                      i18n("Attribute: %1", QString::fromUtf8(localKey)),
                                       QString::fromUtf8(localAttributes.value(localKey)),
                                       QString());
             } else {
                 const QByteArray localValue = localAttributes.value(localKey);
                 const QByteArray otherValue = otherAttributes.value(localKey);
                 if (localValue != otherValue) {
-                    reporter->addProperty(AbstractDifferencesReporter::ConflictMode, i18n("Attribute: %1", QString::fromUtf8(localKey)),
+                    reporter->addProperty(AbstractDifferencesReporter::ConflictMode,
+                                          i18n("Attribute: %1", QString::fromUtf8(localKey)),
                                           QString::fromUtf8(localValue),
                                           QString::fromUtf8(otherValue));
                 }
@@ -163,7 +170,8 @@ static void compareItems(AbstractDifferencesReporter *reporter, const Akonadi::I
 
         for (const QByteArray &otherKey : otherAttributes) {
             if (!localAttributes.contains(otherKey)) {
-                reporter->addProperty(AbstractDifferencesReporter::AdditionalRightMode, i18n("Attribute: %1", QString::fromUtf8(otherKey)),
+                reporter->addProperty(AbstractDifferencesReporter::AdditionalRightMode,
+                                      i18n("Attribute: %1", QString::fromUtf8(otherKey)),
                                       QString(),
                                       QString::fromUtf8(otherAttributes.value(otherKey)));
             }
@@ -172,26 +180,27 @@ static void compareItems(AbstractDifferencesReporter *reporter, const Akonadi::I
 }
 
 ConflictResolveDialog::ConflictResolveDialog(QWidget *parent)
-    : QDialog(parent), mResolveStrategy(ConflictHandler::UseBothItems)
+    : QDialog(parent)
+    , mResolveStrategy(ConflictHandler::UseBothItems)
 {
     setWindowTitle(i18nc("@title:window", "Conflict Resolution"));
 
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     // Don't use QDialogButtonBox, order is very important (left on the left, right on the right)
-    QHBoxLayout *buttonLayout = new QHBoxLayout();
-    QPushButton *takeLeftButton = new QPushButton(this);
+    auto buttonLayout = new QHBoxLayout();
+    auto takeLeftButton = new QPushButton(this);
     takeLeftButton->setText(i18nc("@action:button", "Take my version"));
     connect(takeLeftButton, &QPushButton::clicked, this, &ConflictResolveDialog::slotUseLocalItemChoosen);
     buttonLayout->addWidget(takeLeftButton);
     takeLeftButton->setObjectName(QStringLiteral("takeLeftButton"));
 
-    QPushButton *takeRightButton = new QPushButton(this);
+    auto takeRightButton = new QPushButton(this);
     takeRightButton->setText(i18nc("@action:button", "Take their version"));
     takeRightButton->setObjectName(QStringLiteral("takeRightButton"));
     connect(takeRightButton, &QPushButton::clicked, this, &ConflictResolveDialog::slotUseOtherItemChoosen);
     buttonLayout->addWidget(takeRightButton);
 
-    QPushButton *keepBothButton = new QPushButton(this);
+    auto keepBothButton = new QPushButton(this);
     keepBothButton->setText(i18nc("@action:button", "Keep both versions"));
     keepBothButton->setObjectName(QStringLiteral("keepBothButton"));
     buttonLayout->addWidget(keepBothButton);
@@ -199,14 +208,15 @@ ConflictResolveDialog::ConflictResolveDialog(QWidget *parent)
 
     keepBothButton->setDefault(true);
 
-
     mView = new QTextBrowser(this);
     mView->setObjectName(QStringLiteral("view"));
     mView->setOpenLinks(false);
 
-    QLabel *docuLabel = new QLabel(i18n("<qt>Your changes conflict with those made by someone else meanwhile.<br>"
-                                        "Unless one version can just be thrown away, you will have to integrate those changes manually.<br>"
-                                        "Click on <a href=\"opentexteditor\">\"Open text editor\"</a> to keep a copy of the texts, then select which version is most correct, then re-open it and modify it again to add what's missing."));
+    QLabel *docuLabel =
+        new QLabel(i18n("<qt>Your changes conflict with those made by someone else meanwhile.<br>"
+                        "Unless one version can just be thrown away, you will have to integrate those changes manually.<br>"
+                        "Click on <a href=\"opentexteditor\">\"Open text editor\"</a> to keep a copy of the texts, then select which version is most correct, "
+                        "then re-open it and modify it again to add what's missing."));
     connect(docuLabel, &QLabel::linkActivated, this, &ConflictResolveDialog::slotOpenEditor);
     docuLabel->setContextMenuPolicy(Qt::NoContextMenu);
 
@@ -220,8 +230,7 @@ ConflictResolveDialog::ConflictResolveDialog(QWidget *parent)
     // default size is tiny, and there's usually lots of text, so make it much bigger
     create(); // ensure a window is created
     const QSize availableSize = windowHandle()->screen()->availableSize();
-    windowHandle()->resize(static_cast<int>(availableSize.width() * 0.7),
-                           static_cast<int>(availableSize.height() * 0.5));
+    windowHandle()->resize(static_cast<int>(availableSize.width() * 0.7), static_cast<int>(availableSize.height() * 0.5));
     KWindowConfig::restoreWindowSize(windowHandle(), KSharedConfig::openConfig()->group("ConflictResolveDialog"));
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
@@ -241,7 +250,6 @@ void ConflictResolveDialog::setConflictingItems(const Akonadi::Item &localItem,
     compareItems(&reporter, localItem, otherItem);
 
     if (mLocalItem.hasPayload() && mOtherItem.hasPayload()) {
-
         QObject *object = TypePluginLoader::objectForMimeTypeAndClass(localItem.mimeType(), localItem.availablePayloadMetaTypeIds());
         if (object) {
             DifferencesAlgorithmInterface *algorithm = qobject_cast<DifferencesAlgorithmInterface *>(object);
@@ -253,7 +261,8 @@ void ConflictResolveDialog::setConflictingItems(const Akonadi::Item &localItem,
             }
         }
 
-        reporter.addProperty(HtmlDifferencesReporter::NormalMode, i18n("Data"),
+        reporter.addProperty(HtmlDifferencesReporter::NormalMode,
+                             i18n("Data"),
                              QString::fromUtf8(mLocalItem.payloadData()),
                              QString::fromUtf8(mOtherItem.payloadData()));
     }
